pub struct SolverBuilder { /* private fields */ }Implementations
Sourceimpl SolverBuilder
impl SolverBuilder
Sourcepub fn board_evaluator<T>(self, evaluator: T) -> Selfwhere
T: BoardEvaluator + 'static,
pub fn board_evaluator<T>(self, evaluator: T) -> Selfwhere
T: BoardEvaluator + 'static,
Sets the BoardEvaluator implementation to use in the solver
Sourcepub fn proba_4(self, proba_4: f32) -> Self
pub fn proba_4(self, proba_4: f32) -> Self
Sets the probability weight associated to the draw of a 4 tile
Sourcepub fn base_max_search_depth(self, max_search_depth: usize) -> Self
pub fn base_max_search_depth(self, max_search_depth: usize) -> Self
Sets the max search depth which will be used in the expectiminimax algorithm This value is adjusted at each move to take into account the difficulty of the board. It is thus the max depth which will be used in easy configurations. The effective max depth will be higher for more difficult ones.
Sourcepub fn min_branch_proba(self, proba: f32) -> Self
pub fn min_branch_proba(self, proba: f32) -> Self
Sets the minimum probability for a branch to be explored
pub fn build(self) -> Solver